==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/ar_utf8.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ar_utf8.php,v 1.11 2005/12/07 15:02:08 bigmichi1 Exp $
//
//Translated to arabic by: Nizar Abed  - nizar@srcget.com - Adios

$charset                = 'utf-8';

$text['title']          = 'معلومات عن ألنظام';

$text['vitals']         = 'حيويه';
$text['hostname']       = ' ألمحطه';
$text['ip']             = 'IP عنوان أل';
$text['kversion']       = 'إصدار رقم';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'مدة ألتشغيل';
$text['users']          = 'مستخدمون';
$text['loadavg']        = 'معدل ألتشغيل';

$text['hardware']       = 'معلومات ألمعدات';
$text['numcpu']         = 'وحدات ألمعالجه';
$text['cpumodel']       = 'نوع';
$text['cpuspeed']       = 'سرعه في';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = ' cache سعة ذاكرة';
$text['bogomips']       = 'Bogomips سرعه في';

$text['pci']            = 'PCI معدات ';
$text['ide']            = 'IDE معدات';
$text['scsi']           = 'SCSI معدات';
$text['usb']            = 'USB معدات';

$text['netusage']       = 'إستعمال ألشبكه';
$text['device']         = 'معدات';
$text['received']       = 'إستقبل حتى ألآن';
$text['sent']           = 'أرسل';
$text['errors']         = 'أخطاء';

$text['connections']    = 'إتصالات شبكه منفذه';

$text['memusage']       = 'ذاكره مستعمله';
$text['phymem']         = 'ذاكره جسديه';
$text['swap']           = 'Swap ذاكرة';

$text['fs']             = 'أنظمة ملفات مخططه';
$text['mount']          = 'مخطط';
$text['partition']      = 'تقطيع';

$text['percent']        = 'سعه بألنسبه ألمؤيه';
$text['type']           = 'نوع';
$text['free']           = 'حر';
$text['used']           = 'مستعمل';
$text['size']           = 'حجم';
$text['totals']         = 'مجموع';

$text['kb']             = ' كيلو بايت KB';
$text['mb']             = 'ميغا بايت MB';
$text['gb']             = 'جيغا بايت GB';

$text['none']           = 'بدون';

$text['capacity']       = 'سعه'; 

$text['template']       = 'بنيه';
$text['language']       = 'لغه';
$text['submit']         = 'أدخل';
$text['created']        = 'إصدر بواسطة';

$text['days']           = 'أيام';
$text['hours']          = 'ساعات';
$text['minutes']        = 'دفائق';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

$text['locale']		= 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';
?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/ar_utf8.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ar_utf8.php,v 1.13 2006/06/05 11:48:16 bigmichi1 Exp $
//
//Translated to arabic by: Nizar Abed  - nizar@srcget.com - Adios

$charset                = 'utf-8';

$text['title']          = 'معلومات عن ألنظام';

$text['vitals']         = 'حيويه';
$text['hostname']       = ' ألمحطه';
$text['ip']             = 'IP عنوان أل';
$text['kversion']       = 'إصدار رقم';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'مدة ألتشغيل';
$text['users']          = 'مستخدمون';
$text['loadavg']        = 'معدل ألتشغيل';

$text['hardware']       = 'معلومات ألمعدات';
$text['numcpu']         = 'وحدات ألمعالجه';
$text['cpumodel']       = 'نوع';
$text['cpuspeed']       = 'سرعه في';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = ' cache سعة ذاكرة';
$text['bogomips']       = 'Bogomips سرعه في';

$text['pci']            = 'PCI معدات ';
$text['ide']            = 'IDE معدات';
$text['scsi']           = 'SCSI معدات';
$text['usb']            = 'USB معدات';

$text['netusage']       = 'إستعمال ألشبكه';
$text['device']         = 'معدات';
$text['received']       = 'إستقبل حتى ألآن';
$text['sent']           = 'أرسل';
$text['errors']         = 'أخطاء';

$text['connections']    = 'إتصالات شبكه منفذه';

$text['memusage']       = 'ذاكره مستعمله';
$text['phymem']         = 'ذاكره جسديه';
$text['swap']           = 'Swap ذاكرة';

$text['fs']             = 'أنظمة ملفات مخططه';
$text['mount']          = 'مخطط';
$text['partition']      = 'تقطيع';

$text['percent']        = 'سعه بألنسبه ألمؤيه';
$text['type']           = 'نوع';
$text['free']           = 'حر';
$text['used']           = 'مستعمل';
$text['size']           = 'حجم';
$text['totals']         = 'مجموع';

$text['kb']             = ' كيلو بايت KB';
$text['mb']             = 'ميغا بايت MB';
$text['gb']             = 'جيغا بايت GB';

$text['none']           = 'بدون';

$text['capacity']       = 'سعه'; 

$text['template']       = 'بنيه';
$text['language']       = 'لغه';
$text['submit']         = 'أدخل';
$text['created']        = 'إصدر بواسطة';

$text['days']           = 'أيام';
$text['hours']          = 'ساعات';
$text['minutes']        = 'دفائق';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['locale']		= 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';
?>
